Lock

Struct Lock 

pub struct Lock { /* private fields */ }
File-backed cross-process exclusive lock. See the module docs for what it’s for (and what it isn’t).

Implementations

Source

impl Lock

pub fn open(path: &Path) -> StoreResult<Self>

Opens or creates the lock file at path.

Errors

Returns an error if the file cannot be opened or created.

pub fn lock(&self) -> StoreResult<LockGuard>

Acquires the exclusive lock.

Errors

Returns an error if the lock cannot be acquired.

pub fn try_lock(&self) -> StoreResult<Option<LockGuard>>

Attempts to acquire the exclusive lock without blocking.

Errors

Returns an error if the lock attempt fails for reasons other than the lock being held by another process.