pub struct Row<'stmt, 'conn> { /* private fields */ }Expand description
A guard that represents the current row for a statement.
Values read through this guard are valid for the current row only.
Calling step, reset, or dropping/finalizing the statement invalidates
SQLite’s internal row pointers.
Implementations
Sourceimpl Row<'_, '_>
impl Row<'_, '_>
Sourcepub fn column_i64(&self, idx: usize) -> i64
pub fn column_i64(&self, idx: usize) -> i64
Sourcepub fn column_text(&self, idx: usize) -> String
pub fn column_text(&self, idx: usize) -> String
Reads a column as a UTF-8 string. Returns an empty string for NULL.
Panics
Panics if idx exceeds i32::MAX.
Sourcepub fn is_column_null(&self, idx: usize) -> bool
pub fn is_column_null(&self, idx: usize) -> bool